==> moodle_1.3.1.orig.tar.gz: moodle/lang/th/countries.php <==
<?PHP // $Id: countries.php,v 1.1 2004/03/19 06:30:20 moodler Exp $ 
      // countries.php - created with Moodle 1.2 Beta (2004022400)


$string['AD'] = 'ѹ';
$string['AE'] = 'Ѻõ';
$string['AF'] = 'ѿҹʶҹ';
$string['AG'] = 'ѹԡкҺٴ';
$string['AI'] = 'ѧ';
$string['AL'] = 'ź';
$string['AM'] = '';
$string['AN'] = 'Ź ͹';
$string['AO'] = 'ͧ';
$string['AQ'] = '͹졵ԡ';
$string['AR'] = 'ਹԹ';
$string['AS'] = 'ԡѹ';
$string['AT'] = '';
$string['AU'] = '';
$string['AW'] = 'ٺ';
$string['AZ'] = '亨ѹ';
$string['BA'] = 'Թ';
$string['BB'] = '';
$string['BD'] = 'ѧ';
$string['BE'] = '';
$string['BF'] = '͡Թҿ';
$string['BG'] = 'š';
$string['BH'] = 'ù';
$string['BI'] = 'ع';
$string['BJ'] = 'ູԹ';
$string['BM'] = 'Ǵ';
$string['BN'] = '';
$string['BO'] = '';
$string['BR'] = 'ҫ';
$string['BS'] = '';
$string['BT'] = 'ٮҹ';
$string['BV'] = 'ǷŹ';
$string['BW'] = 'ͷҹ';
$string['BY'] = '';
$string['BZ'] = 'ԫ';
$string['CA'] = '᤹Ҵ';
$string['CC'] = '⤤Ź';
$string['CF'] = 'ҸóѰѿԡҡҧ';
$string['CG'] = 'ͧ';
$string['CH'] = 'ԷŹ';
$string['CI'] = '';
$string['CK'] = 'ءŹ';
$string['CL'] = '';
$string['CM'] = 'ٹ';
$string['CN'] = 'չ';
$string['CO'] = '';
$string['CR'] = 'ʵԡ';
$string['CS'] = 'ͧ';
$string['CU'] = 'Ǻ';
$string['CV'] = 'ऻ';
$string['CX'] = 'ʵŹ';
$string['CY'] = '䫻';
$string['CZ'] = 'ҸóѰત';
$string['DE'] = 'ѹ';
$string['DJ'] = 'ըԺص';
$string['DK'] = 'ഹ';
$string['DM'] = 'Թԡ';
$string['DO'] = 'ҸóѰԹԡѹ';
$string['DZ'] = 'Ũ';
$string['EC'] = '͡Ǵ';
$string['EE'] = '';
$string['EG'] = 'Ի';
$string['EH'] = 'ҵѹ';
$string['ER'] = '';
$string['ES'] = '໹';
$string['ET'] = 'ͷ';
$string['FI'] = 'ԹŹ';
$string['FJ'] = 'Ԩ';
$string['FK'] = 'пŹ';
$string['FM'] = '˾ѹѰ';
$string['FO'] = 'п';
$string['FR'] = '';
$string['FX'] = ' ᷹';
$string['GA'] = 'Һͧ';
$string['GB'] = 'ѧ';
$string['GD'] = 'ùҴ';
$string['GE'] = '';
$string['GF'] = 'ùҹ';
$string['GH'] = 'ҹ';
$string['GI'] = 'Ժŵ';
$string['GL'] = 'չŹ';
$string['GM'] = '';
$string['GN'] = 'Թ';
$string['GP'] = 'ٻ';
$string['GQ'] = 'Թաҧ';
$string['GR'] = 'ի';
$string['GT'] = '';
$string['GU'] = '';
$string['GW'] = 'Թպԫ';
$string['GY'] = 'ҹ';
$string['HK'] = 'ͧ';
$string['HM'] = ' ⴹŴ';
$string['HN'] = '͹';
$string['HR'] = '';
$string['HT'] = 'ε';
$string['HU'] = 'ѧ';
$string['ID'] = 'Թⴹ';
$string['IE'] = 'Ź';
$string['IL'] = '';
$string['IN'] = 'Թ';
$string['IO'] = 'ҳҹԤҺطúԵԪԹ';
$string['IQ'] = 'ѡ';
$string['IR'] = 'ҹ';
$string['IS'] = 'ͫŹ';
$string['IT'] = 'Ե';
$string['JM'] = '';
$string['JO'] = 'ᴹ';
$string['JP'] = '';
$string['KE'] = 'ह';
$string['KG'] = '䤡ʶҹ';
$string['KH'] = '٪';
$string['KI'] = 'Ժҵ';
$string['KM'] = '';
$string['KN'] = 'ૹԵ ';
$string['KO'] = '';
$string['KP'] = 'ҸóѰЪҸԻ»ЪҪ';
$string['KR'] = 'ҸóѰ';
$string['KW'] = 'ǵ';
$string['KY'] = '';
$string['KZ'] = 'ҫѤʶҹ';
$string['LA'] = 'ҸóѰЪҸԻ»ЪҪ';
$string['LB'] = 'źҹ͹';
$string['LC'] = 'ૹ';
$string['LI'] = 'Ԥ൹䵹';
$string['LK'] = 'ѧ';
$string['LR'] = '';
$string['LS'] = '';
$string['LT'] = 'Ը';
$string['LU'] = 'ѡ';
$string['LV'] = 'ŵ';
$string['LY'] = 'Ժѹ Ѻ ';
$string['MA'] = 'ͤ';
$string['MC'] = '';
$string['MD'] = 'ҸóѰ';
$string['MG'] = 'Ҵҡʡ';
$string['MH'] = '';
$string['MK'] = '';
$string['ML'] = '';
$string['MM'] = '¹';
$string['MN'] = 'ͧ';
$string['MO'] = '';
$string['MP'] = '¹˹';
$string['MQ'] = 'ҷԹԤ';
$string['MR'] = 'Է';
$string['MS'] = 'ͧ÷';
$string['MT'] = 'ŵ';
$string['MU'] = '';
$string['MV'] = 'Ŵտ';
$string['MW'] = '';
$string['MX'] = '';
$string['MY'] = '';
$string['MZ'] = 'ԡ';
$string['NA'] = '';
$string['NC'] = 'Ǥ';
$string['NE'] = '';
$string['NF'] = 'й';
$string['NG'] = '乨';
$string['NI'] = 'Ԥҡ';
$string['NL'] = 'Ź';
$string['NO'] = '';
$string['NP'] = '๻';
$string['NR'] = '';
$string['NU'] = '';
$string['NZ'] = 'ǫŹ';
$string['OM'] = 'ҹ';
$string['PA'] = 'ҹ';
$string['PE'] = '';
$string['PF'] = 'ù';
$string['PG'] = 'һǹǡԹ';
$string['PH'] = 'ԻԹ';
$string['PK'] = 'ҡʶҹ';
$string['PL'] = 'Ź';
$string['PM'] = 'ૹ ͹';
$string['PN'] = 'Է';
$string['PR'] = '';
$string['PT'] = '⻵';
$string['PW'] = '';
$string['PY'] = 'ҡ';
$string['QA'] = 'ҵ';
$string['RE'] = '¹';
$string['RO'] = '';
$string['RU'] = '˾ѹѰ';
$string['RW'] = 'ѹ';
$string['SA'] = 'ش';
$string['SB'] = '͹';
$string['SC'] = '';
$string['SD'] = 'ٴҹ';
$string['SE'] = 'ഹ';
$string['SG'] = 'ԧ';
$string['SH'] = 'ૹŹ';
$string['SI'] = '';
$string['SJ'] = 'ЫҺѴ  ᨹ¹';
$string['SK'] = '';
$string['SL'] = ' ͧ';
$string['SM'] = 'ҹ';
$string['SN'] = '๡';
$string['SO'] = '';
$string['SR'] = 'Թ';
$string['ST'] = ' Թ';
$string['SV'] = 'ūҴ';
$string['SY'] = 'ҸóѰ¹Ѻ';
$string['SZ'] = 'ҫŹ';
$string['TC'] = '䤤';
$string['TD'] = 'Ҵ';
$string['TF'] = 'ҳҹԤ';
$string['TG'] = '';
$string['TH'] = '';
$string['TJ'] = 'Ҩԡʶҹ';
$string['TK'] = '';
$string['TM'] = 'ʶҹ';
$string['TN'] = 'ٹ';
$string['TO'] = 'ͧ';
$string['TP'] = 'ѹ͡';
$string['TR'] = 'á';
$string['TT'] = 'Թᴴ⵺';
$string['TV'] = '';
$string['TW'] = 'ѹ';
$string['TZ'] = '᷹';
$string['UA'] = 'ù';
$string['UG'] = '١ѹ';
$string['US'] = 'ԡ';
$string['UY'] = 'ء';
$string['UZ'] = 'ມʶҹ';
$string['VA'] = 'ҵԡѹԵ';
$string['VC'] = 'ૹԹૹùҴչ';
$string['VE'] = '๫';
$string['VG'] = 'Թ (ѧ)';
$string['VI'] = 'Թ (ԡ)';
$string['VN'] = '´';
$string['VU'] = 'ҹǵ';
$string['WA'] = '';
$string['WF'] = 'пٹ';
$string['WS'] = '';
$string['YE'] = '';
$string['YT'] = 'µ';
$string['ZA'] = 'ѿԡ';
$string['ZM'] = '';
$string['ZR'] = '';
$string['ZW'] = 'Ѻ';

?>

==> moodle_1.4.3.orig.tar.gz: moodle/lang/th/countries.php <==
<?PHP // $Id$ 
      // countries.php - created with Moodle 1.5 unstable development (2004083000)


$string['AD'] = 'ѹ';
$string['AE'] = 'Ѻõ';
$string['AF'] = 'ѿҹʶҹ';
$string['AG'] = 'ѹԡкҺٴ';
$string['AI'] = 'ѧ';
$string['AL'] = 'ź';
$string['AM'] = '';
$string['AN'] = 'Ź ͹';
$string['AO'] = 'ͧ';
$string['AQ'] = '͹졵ԡ';
$string['AR'] = 'ਹԹ';
$string['AS'] = 'ԡѹ';
$string['AT'] = '';
$string['AU'] = '';
$string['AW'] = 'ٺ';
$string['AZ'] = '亨ѹ';
$string['BA'] = 'Թ';
$string['BB'] = '';
$string['BD'] = 'ѧ';
$string['BE'] = '';
$string['BF'] = '͡Թҿ';
$string['BG'] = 'š';
$string['BH'] = 'ù';
$string['BI'] = 'ع';
$string['BJ'] = 'ູԹ';
$string['BM'] = 'Ǵ';
$string['BN'] = '';
$string['BO'] = '';
$string['BR'] = 'ҫ';
$string['BS'] = '';
$string['BT'] = 'ٮҹ';
$string['BV'] = 'ǷŹ';
$string['BW'] = 'ͷҹ';
$string['BY'] = '';
$string['BZ'] = 'ԫ';
$string['CA'] = '᤹Ҵ';
$string['CC'] = '⤤Ź';
$string['CF'] = 'ҸóѰѿԡҡҧ';
$string['CG'] = 'ͧ';
$string['CH'] = 'ԷŹ';
$string['CI'] = '';
$string['CK'] = 'ءŹ';
$string['CL'] = '';
$string['CM'] = 'ٹ';
$string['CN'] = 'չ';
$string['CO'] = '';
$string['CR'] = 'ʵԡ';
$string['CS'] = 'ͧ';
$string['CU'] = 'Ǻ';
$string['CV'] = 'ऻ';
$string['CX'] = 'ʵŹ';
$string['CY'] = '䫻';
$string['CZ'] = 'ҸóѰત';
$string['DE'] = 'ѹ';
$string['DJ'] = 'ըԺص';
$string['DK'] = 'ഹ';
$string['DM'] = 'Թԡ';
$string['DO'] = 'ҸóѰԹԡѹ';
$string['DZ'] = 'Ũ';
$string['EC'] = '͡Ǵ';
$string['EE'] = '';
$string['EG'] = 'Ի';
$string['EH'] = 'ҵѹ';
$string['ER'] = '';
$string['ES'] = '໹';
$string['ET'] = 'ͷ';
$string['FI'] = 'ԹŹ';
$string['FJ'] = 'Ԩ';
$string['FK'] = 'пŹ';
$string['FM'] = '˾ѹѰ';
$string['FO'] = 'п';
$string['FR'] = '';
$string['FX'] = ' ᷹';
$string['GA'] = 'Һͧ';
$string['GB'] = 'ѧ';
$string['GD'] = 'ùҴ';
$string['GE'] = '';
$string['GF'] = 'ùҹ';
$string['GH'] = 'ҹ';
$string['GI'] = 'Ժŵ';
$string['GL'] = 'չŹ';
$string['GM'] = '';
$string['GN'] = 'Թ';
$string['GP'] = 'ٻ';
$string['GQ'] = 'Թաҧ';
$string['GR'] = 'ի';
$string['GT'] = '';
$string['GU'] = '';
$string['GW'] = 'Թպԫ';
$string['GY'] = 'ҹ';
$string['HK'] = 'ͧ';
$string['HM'] = ' ⴹŴ';
$string['HN'] = '͹';
$string['HR'] = '';
$string['HT'] = 'ε';
$string['HU'] = 'ѧ';
$string['ID'] = 'Թⴹ';
$string['IE'] = 'Ź';
$string['IL'] = '';
$string['IN'] = 'Թ';
$string['IO'] = 'ҳҹԤҺطúԵԪԹ';
$string['IQ'] = 'ѡ';
$string['IR'] = 'ҹ';
$string['IS'] = 'ͫŹ';
$string['IT'] = 'Ե';
$string['JM'] = '';
$string['JO'] = 'ᴹ';
$string['JP'] = '';
$string['KE'] = 'ह';
$string['KG'] = '䤡ʶҹ';
$string['KH'] = '٪';
$string['KI'] = 'Ժҵ';
$string['KM'] = '';
$string['KN'] = 'ૹԵ ';
$string['KO'] = '';
$string['KP'] = 'ҸóѰЪҸԻ»ЪҪ';
$string['KR'] = 'ҸóѰ';
$string['KW'] = 'ǵ';
$string['KY'] = '';
$string['KZ'] = 'ҫѤʶҹ';
$string['LA'] = 'ҸóѰЪҸԻ»ЪҪ';
$string['LB'] = 'źҹ͹';
$string['LC'] = 'ૹ';
$string['LI'] = 'Ԥ൹䵹';
$string['LK'] = 'ѧ';
$string['LR'] = '';
$string['LS'] = '';
$string['LT'] = 'Ը';
$string['LU'] = 'ѡ';
$string['LV'] = 'ŵ';
$string['LY'] = 'Ժѹ Ѻ ';
$string['MA'] = 'ͤ';
$string['MC'] = '';
$string['MD'] = 'ҸóѰ';
$string['MG'] = 'Ҵҡʡ';
$string['MH'] = '';
$string['MK'] = '';
$string['ML'] = '';
$string['MM'] = '¹';
$string['MN'] = 'ͧ';
$string['MO'] = '';
$string['MP'] = '¹˹';
$string['MQ'] = 'ҷԹԤ';
$string['MR'] = 'Է';
$string['MS'] = 'ͧ÷';
$string['MT'] = 'ŵ';
$string['MU'] = '';
$string['MV'] = 'Ŵտ';
$string['MW'] = '';
$string['MX'] = '';
$string['MY'] = '';
$string['MZ'] = 'ԡ';
$string['NA'] = '';
$string['NC'] = 'Ǥ';
$string['NE'] = '';
$string['NF'] = 'й';
$string['NG'] = '乨';
$string['NI'] = 'Ԥҡ';
$string['NL'] = 'Ź';
$string['NO'] = '';
$string['NP'] = '๻';
$string['NR'] = '';
$string['NU'] = '';
$string['NZ'] = 'ǫŹ';
$string['OM'] = 'ҹ';
$string['PA'] = 'ҹ';
$string['PE'] = '';
$string['PF'] = 'ù';
$string['PG'] = 'һǹǡԹ';
$string['PH'] = 'ԻԹ';
$string['PK'] = 'ҡʶҹ';
$string['PL'] = 'Ź';
$string['PM'] = 'ૹ ͹';
$string['PN'] = 'Է';
$string['PR'] = '';
$string['PS'] = '䵹';
$string['PT'] = '⻵';
$string['PW'] = '';
$string['PY'] = 'ҡ';
$string['QA'] = 'ҵ';
$string['RE'] = '¹';
$string['RO'] = '';
$string['RU'] = '˾ѹѰ';
$string['RW'] = 'ѹ';
$string['SA'] = 'ش';
$string['SB'] = '͹';
$string['SC'] = '';
$string['SD'] = 'ٴҹ';
$string['SE'] = 'ഹ';
$string['SG'] = 'ԧ';
$string['SH'] = 'ૹŹ';
$string['SI'] = '';
$string['SJ'] = 'ЫҺѴ  ᨹ¹';
$string['SK'] = '';
$string['SL'] = ' ͧ';
$string['SM'] = 'ҹ';
$string['SN'] = '๡';
$string['SO'] = '';
$string['SR'] = 'Թ';
$string['ST'] = ' Թ';
$string['SV'] = 'ūҴ';
$string['SY'] = 'ҸóѰ¹Ѻ';
$string['SZ'] = 'ҫŹ';
$string['TC'] = '䤤';
$string['TD'] = 'Ҵ';
$string['TF'] = 'ҳҹԤ';
$string['TG'] = '';
$string['TH'] = '';
$string['TJ'] = 'Ҩԡʶҹ';
$string['TK'] = '';
$string['TM'] = 'ʶҹ';
$string['TN'] = 'ٹ';
$string['TO'] = 'ͧ';
$string['TP'] = 'ѹ͡';
$string['TR'] = 'á';
$string['TT'] = 'Թᴴ⵺';
$string['TV'] = '';
$string['TW'] = 'ѹ';
$string['TZ'] = '᷹';
$string['UA'] = 'ù';
$string['UG'] = '١ѹ';
$string['US'] = 'ԡ';
$string['UY'] = 'ء';
$string['UZ'] = 'ມʶҹ';
$string['VA'] = 'ҵԡѹԵ';
$string['VC'] = 'ૹԹૹùҴչ';
$string['VE'] = '๫';
$string['VG'] = 'Թ (ѧ)';
$string['VI'] = 'Թ (ԡ)';
$string['VN'] = '´';
$string['VU'] = 'ҹǵ';
$string['WA'] = '';
$string['WF'] = 'пٹ';
$string['WS'] = '';
$string['YE'] = '';
$string['YT'] = 'µ';
$string['ZA'] = 'ѿԡ';
$string['ZM'] = '';
$string['ZR'] = '';
$string['ZW'] = 'Ѻ';

?>
